import numpy as np
import optuna
import xgboost
from sklearn.metrics import (
    accuracy_score,
    confusion_matrix,
    explained_variance_score,
    f1_score,
    make_scorer,
    max_error,
    mean_absolute_error,
    mean_absolute_percentage_error,
    mean_squared_error,
    median_absolute_error,
    precision_score,
    r2_score,
    recall_score,
    roc_auc_score,
)
from sklearn.model_selection import (
    GridSearchCV,
    RandomizedSearchCV,
    StratifiedKFold,
    train_test_split,
)


def _trail_param_retrive(trial, dict, keyword):
    """Function for calculating best estimator
    Parameters
    ----------
    estimator : estimator instance
        An unfitted estimator.
    cv : object, cross-validation object, default=None
    Attributes
    ----------
    n_features_in_ : int
    Number of features seen during :term:`fit`. Only defined if the
    underlying estimator exposes such an attribute when fit.
    .. versionadded:: 0.24

    """
    if keyword == "max_depth":
        return trial.suggest_int(
            keyword, min(dict[keyword]), max(dict[keyword]), log=True
        )
    else:
        return trial.suggest_float(
            keyword, min(dict[keyword]), max(dict[keyword]), log=True
        )


def calc_metric_for_multi_outputs_classification(label, valid_y, preds, SCORE_TYPE):
    """Function for calculating best estimator
    Parameters
    ----------
    estimator : estimator instance
        An unfitted estimator.
    cv : object, cross-validation object, default=None
    Attributes
    ----------
    n_features_in_ : int
    Number of features seen during :term:`fit`. Only defined if the
    underlying estimator exposes such an attribute when fit.
    .. versionadded:: 0.24

    """

    sum_errors = 0

    for i, l in enumerate(label):
        f1 = f1_score(valid_y[l], preds[:, i])
        acc = accuracy_score(valid_y[l], preds[:, i])
        pr = precision_score(valid_y[l], preds[:, i])
        recall = recall_score(valid_y[l], preds[:, i])
        roc = roc_auc_score(valid_y[l], preds[:, i])
        tn, fp, fn, tp = confusion_matrix(
            valid_y[l], preds[:, i], labels=[0, 1]
        ).ravel()

        if SCORE_TYPE == "f1" or SCORE_TYPE == "f1_score":
            sum_errors = sum_errors + f1
        if (
            SCORE_TYPE == "acc"
            or SCORE_TYPE == "accuracy_score"
            or SCORE_TYPE == "accuracy"
        ):
            sum_errors = sum_errors + acc
        if (
            SCORE_TYPE == "pr"
            or SCORE_TYPE == "precision_score"
            or SCORE_TYPE == "precision"
        ):
            sum_errors = sum_errors + pr
        if (
            SCORE_TYPE == "recall"
            or SCORE_TYPE == "recall_score"
            or SCORE_TYPE == "recall"
        ):
            sum_errors = sum_errors + recall
        if (
            SCORE_TYPE == "roc"
            or SCORE_TYPE == "roc_auc_score"
            or SCORE_TYPE == "roc_auc"
        ):
            sum_errors = sum_errors + roc

        # other metrics - not often use

        if SCORE_TYPE == "tp" or SCORE_TYPE == "true possitive":
            sum_errors = sum_errors + tp
        if SCORE_TYPE == "tn" or SCORE_TYPE == "true negative":
            sum_errors = sum_errors + tn

    return sum_errors


def _calc_metric_for_single_output_classification(valid_y, pred_labels, SCORE_TYPE):
    """Function for calculating best estimator
    Parameters
    ----------
    estimator : estimator instance
        An unfitted estimator.
    cv : object, cross-validation object, default=None
    Attributes
    ----------
    n_features_in_ : int
    Number of features seen during :term:`fit`. Only defined if the
    underlying estimator exposes such an attribute when fit.
    .. versionadded:: 0.24

    """

    sum_errors = 0
    f1 = f1_score(valid_y, pred_labels)
    acc = accuracy_score(valid_y, pred_labels)
    pr = precision_score(valid_y, pred_labels)
    recall = recall_score(valid_y, pred_labels)
    roc = roc_auc_score(valid_y, pred_labels)

    tn, _, _, tp = confusion_matrix(valid_y, pred_labels, labels=[0, 1]).ravel()
    if SCORE_TYPE == "f1" or SCORE_TYPE == "f1_score":
        sum_errors = sum_errors + f1
    if (
        SCORE_TYPE == "acc"
        or SCORE_TYPE == "accuracy_score"
        or SCORE_TYPE == "accuracy"
    ):
        sum_errors = sum_errors + acc
    if (
        SCORE_TYPE == "pr"
        or SCORE_TYPE == "precision_score"
        or SCORE_TYPE == "precision"
    ):
        sum_errors = sum_errors + pr
    if SCORE_TYPE == "recall" or SCORE_TYPE == "recall_score" or SCORE_TYPE == "recall":
        sum_errors = sum_errors + recall
    if SCORE_TYPE == "roc" or SCORE_TYPE == "roc_auc_score" or SCORE_TYPE == "roc_auc":
        sum_errors = sum_errors + roc

    # other metrics - not often use

    if SCORE_TYPE == "tp" or SCORE_TYPE == "true possitive":
        sum_errors = sum_errors + tp
    if SCORE_TYPE == "tn" or SCORE_TYPE == "true negative":
        sum_errors = sum_errors + tn

    return sum_errors


def _calc_metric_for_single_output_regression(valid_y, pred_labels, SCORE_TYPE):
    """Function for calculating best estimator
    Parameters
    ----------
    estimator : estimator instance
        An unfitted estimator.
    cv : object, cross-validation object, default=None
    Attributes
    ----------
    n_features_in_ : int
    Number of features seen during :term:`fit`. Only defined if the
    underlying estimator exposes such an attribute when fit.
    .. versionadded:: 0.24

    """

    r2 = r2_score(valid_y, pred_labels)
    explained_variance_score_sr = explained_variance_score(valid_y, pred_labels)

    max_error_err = max_error(valid_y, pred_labels)
    mean_absolute_error_err = mean_absolute_error(valid_y, pred_labels)
    mean_squared_error_err = mean_squared_error(valid_y, pred_labels)
    median_absolute_error_err = median_absolute_error(valid_y, pred_labels)
    mean_absolute_percentage_error_err = mean_absolute_percentage_error(
        valid_y, pred_labels
    )

    if SCORE_TYPE == "r2" or SCORE_TYPE == "r2_score":
        return r2
    if SCORE_TYPE == "explained_variance_score":
        return explained_variance_score_sr

    if SCORE_TYPE == "max_error":
        return max_error_err
    if SCORE_TYPE == "mean_absolute_error":
        return mean_absolute_error_err
    if SCORE_TYPE == "mean_squared_error":
        return mean_squared_error_err
    if SCORE_TYPE == "median_absolute_error":
        return median_absolute_error_err
    if SCORE_TYPE == "mean_absolute_percentage_error":
        return mean_absolute_percentage_error_err


def _calc_best_estimator_grid_search(
    X, y, estimator, estimator_params, measure_of_accuracy, verbose, n_jobs, cv
):
    """Function for calculating best estimator
    Parameters
    ----------
    estimator : estimator instance
        An unfitted estimator.
    cv : object, cross-validation object, default=None
    Attributes
    ----------
    n_features_in_ : int
    Number of features seen during :term:`fit`. Only defined if the
    underlying estimator exposes such an attribute when fit.
    .. versionadded:: 0.24

    """
    grid_search = GridSearchCV(
        estimator,
        param_grid=estimator_params,
        cv=cv,
        n_jobs=n_jobs,
        scoring=make_scorer(measure_of_accuracy),
        verbose=verbose,
    )
    grid_search.fit(X, y)
    best_estimator = grid_search.best_estimator_
    return best_estimator


def _calc_best_estimator_random_search(
    X, y, estimator, estimator_params, measure_of_accuracy, verbose, n_jobs, n_iter, cv
):
    """Function for calculating best estimator
    Parameters
    ----------
    estimator : estimator instance
        An unfitted estimator.
    cv : object, cross-validation object, default=None
    Attributes
    ----------
    n_features_in_ : int
    Number of features seen during :term:`fit`. Only defined if the
    underlying estimator exposes such an attribute when fit.

    """
    random_search = RandomizedSearchCV(
        estimator,
        param_distributions=estimator_params,
        cv=cv,
        n_iter=n_iter,
        n_jobs=n_jobs,
        scoring=make_scorer(measure_of_accuracy),
        verbose=verbose,
    )
    random_search.fit(X, y)
    best_estimator = random_search.best_estimator_
    return best_estimator


def _calc_best_estimator_optuna_univariate(
    X,
    y,
    estimator,
    measure_of_accuracy,
    estimator_params,
    verbose,
    test_size,
    random_state,
    eval_metric,
    number_of_trials,
    sampler,
    pruner,
    with_stratified,
):
    """Function for calculating best estimator
    Parameters
    ----------
    estimator : estimator instance
        An unfitted estimator.
    cv : object, cross-validation object, default=None
    Attributes
    ----------
    n_features_in_ : int
    Number of features seen during :term:`fit`. Only defined if the
    underlying estimator exposes such an attribute when fit.
    .. versionadded:: 0.24

    """
    if estimator.__class__.__name__ == "XGBClassifier" and with_stratified:
        train_x, valid_x, train_y, valid_y = train_test_split(
            X, y, stratify=y[y.columns.to_list()[0]], test_size=test_size
        )
    if estimator.__class__.__name__ == "XGBClassifier" and not with_stratified:
        train_x, valid_x, train_y, valid_y = train_test_split(
            X, y, test_size=test_size, random_state=random_state
        )
    if estimator.__class__.__name__ == "XGBRegressor":
        train_x, valid_x, train_y, valid_y = train_test_split(
            X, y, test_size=test_size, random_state=random_state
        )

    def objective(trial):

        dtrain = xgboost.DMatrix(train_x, label=train_y)
        dvalid = xgboost.DMatrix(valid_x, label=valid_y)

        if (
            estimator.__class__.__name__ == "XGBClassifier"
            or estimator.__class__.__name__ == "XGBRegressor"
        ):
            param = {}
            param["verbosity"] = verbose
            param["eval_metric"] = eval_metric
            param["booster"] = trial.suggest_categorical("booster", ["gbtree"])
            if (
                valid_y.iloc[:, 0].nunique() <= 2
                and estimator.__class__.__name__ == "XGBClassifier"
            ):
                param["objective"] = "binary:logistic"
            if estimator.__class__.__name__ == "XGBRegressor":
                param["objective"] = "reg:squarederror"

            if "lambda" in estimator_params.keys():
                param["lambda"] = _trail_param_retrive(
                    trial, estimator_params, "lambda"
                )
            # L1 regularization weight.
            if "alpha" in estimator_params.keys():
                param["alpha"] = _trail_param_retrive(trial, estimator_params, "alpha")
            # sampling ratio for training data.
            if "subsample" in estimator_params.keys():
                param["subsample"] = _trail_param_retrive(
                    trial, estimator_params, "subsample"
                )
            # sampling according to each tree.
            if "colsample_bytree" in estimator_params.keys():
                param["colsample_bytree"] = _trail_param_retrive(
                    trial, estimator_params, "colsample_bytree"
                )
            if estimator.__class__.__name__ == "XGBClassifier":
                if "scale_pos_weight" in estimator_params.keys():
                    param["scale_pos_weight"] = _trail_param_retrive(
                        trial, estimator_params, "scale_pos_weight"
                    )
            if "booster" in estimator_params.keys():
                if param["booster"] in ["gbtree", "dart"]:
                    # maximum depth of the tree, signifies complexity of the tree.
                    if "max_depth" in estimator_params.keys():
                        param["max_depth"] = _trail_param_retrive(
                            trial, estimator_params, "max_depth"
                        )
                    if "min_child_weight" in estimator_params.keys():
                        # minimum child weight, larger the term more conservative the tree.
                        param["min_child_weight"] = _trail_param_retrive(
                            trial, estimator_params, "min_child_weight"
                        )
                    if "eta" in estimator_params.keys():
                        param["eta"] = _trail_param_retrive(
                            trial, estimator_params, "eta"
                        )
                    if "gamma" in estimator_params.keys():
                        # defines how selective algorithm is.
                        param["gamma"] = _trail_param_retrive(
                            trial, estimator_params, "gamma"
                        )
                    # if "grow_policy" in estimator_params.keys():
                    #    param["grow_policy"] = _trail_param_retrive(
                    #        trial, estimator_params, "grow_policy"
                    #    )
            if "booster" in estimator_params.keys():
                if param["booster"] == "dart":
                    if "sample_type" in estimator_params.keys():
                        param["sample_type"] = _trail_param_retrive(
                            trial, estimator_params, "sample_type"
                        )
                    if "normalize_type" in estimator_params.keys():
                        param["normalize_type"] = _trail_param_retrive(
                            trial, estimator_params, "normalize_type"
                        )
                    if "rate_drop" in estimator_params.keys():
                        param["rate_drop"] = _trail_param_retrive(
                            trial, estimator_params, "rate_drop"
                        )
                    if "skip_drop" in estimator_params.keys():
                        param["skip_drop"] = _trail_param_retrive(
                            trial, estimator_params, "skip_drop"
                        )
            # Add a callback for pruning.
            pruning_callback = optuna.integration.XGBoostPruningCallback(
                trial, "validation-" + eval_metric
            )
            est = xgboost.train(
                param,
                dtrain,
                evals=[(dvalid, "validation")],
                callbacks=[pruning_callback],
            )
            preds = est.predict(dvalid)
            pred_labels = np.rint(preds)

            if "classifier" in estimator.__class__.__name__.lower():
                accr = _calc_metric_for_single_output_classification(
                    valid_y, pred_labels, measure_of_accuracy
                )
            if "regressor" in estimator.__class__.__name__.lower():
                accr = _calc_metric_for_single_output_regression(
                    valid_y, pred_labels, measure_of_accuracy
                )

        return accr

    study = optuna.create_study(direction="maximize", sampler=sampler, pruner=pruner)
    study.optimize(objective, n_trials=number_of_trials, timeout=600)
    trial = study.best_trial
    dtrain = xgboost.DMatrix(train_x, label=train_y)
    dvalid = xgboost.DMatrix(valid_x, label=valid_y)
    print(trial.params)

    best_estimator = xgboost.train(
        trial.params,
        dtrain,
        evals=[(dvalid, "validation")],
    )

    return best_estimator



import fasttreeshap
import numpy as np
import pandas as pd
import shap
from optuna.pruners import HyperbandPruner
from optuna.samplers import TPESampler
from sklearn.base import BaseEstimator, TransformerMixin

from zoish.utils.helper_funcs import (
    _calc_best_estimator_grid_search,
    _calc_best_estimator_optuna_univariate,
    _calc_best_estimator_random_search,
)


class ScallyShapFeatureSelector(BaseEstimator, TransformerMixin):
    """Feature Selector class using shap values
    Parameters
    ----------
    estimator : estimator instance
        An unfitted estimator.
    cv : int, cross-validation generator or an iterable, default=None
    n_jobs : int, default=None
        Number of jobs to run in parallel. When evaluating a new feature to
        add or remove, the cross-validation procedure is parallel over the
        folds.
        ``None`` means 1 unless in a :obj:`joblib.parallel_backend` context.
        ``-1`` means using all processors. See :term:`Glossary <n_jobs>`
        for more details.
    Attributes
    ----------
    n_features_in_ : int
        Number of features seen during :term:`fit`. Only defined if the
        underlying estimator exposes such an attribute when fitted .
        .. versionadded:: 0.1

    """

    def __init__(
        self,
        n_features=5,
        estimator=None,
        estimator_params=None,
        hyper_parameter_optimization_method="optuna",
        shap_version="v0",
        measure_of_accuracy=None,
        list_of_obligatory_features=[],
        test_size=0.33,
        cv=3,
        with_shap_summary_plot=False,
        with_shap_interaction_plot=False,
        with_stratified=True,
        verbose=1,
        random_state=0,
        n_jobs=-1,
        n_iter=10,
        eval_metric="auc",
        number_of_trials=100,
        sampler=TPESampler(),
        pruner=HyperbandPruner(),
    ):

        self.n_features = n_features
        self.estimator = estimator
        self.estimator_params = estimator_params
        self.hyper_parameter_optimization_method = hyper_parameter_optimization_method
        self.shap_version = shap_version
        self.measure_of_accuracy = measure_of_accuracy
        self.list_of_obligatory_features = list_of_obligatory_features
        self.test_size = test_size
        self.cv = cv
        self.with_shap_summary_plot = with_shap_summary_plot
        self.with_shap_interaction_plot = with_shap_interaction_plot
        self.with_stratified = with_stratified
        self.verbose = verbose
        self.random_state = random_state
        self.n_jobs = n_jobs
        self.n_iter = n_iter
        self.eval_metric = eval_metric
        self.number_of_trials = number_of_trials
        self.sampler = sampler
        self.pruner = pruner
        self.best_estimator = None
        self.importance_df = None

    @property
    def n_features(self):
        print("Getting value for n_features")
        return self._n_features

    @n_features.setter
    def n_features(self, value):
        print("Setting value for n_features")
        if value < 0:
            raise ValueError("n_features below 0 is not possible")
        self._n_features = value

    @property
    def estimator(self):
        print("Getting value for estimator")
        return self._estimator

    @estimator.setter
    def estimator(self, value):
        print("Setting value for estimator")
        if value.__class__.__name__ not in [
            "XGBRegressor",
            "XGBClassifier",
            "RandomForestClassifier",
            "RandomForestRegressor",
            "CatBoostClassifier",
            "CatBoostRegressor",
            "BalancedRandomForestClassifier",
        ]:

            raise TypeError(
                f"{value.__class__.__name__} \
                 model is not supported yet"
            )
        self._estimator = value

    @property
    def estimator_params(self):
        print("Getting value for estimator_params")
        return self._estimator_params

    @estimator_params.setter
    def estimator_params(self, value):
        print(self.estimator)
        print(self.estimator.get_params().keys())
        if value.keys() <= self.estimator.get_params().keys():
            print("Setting value for estimator_params")
            self._estimator_params = value
        else:
            raise TypeError(
                f"error occures during parameter checking for \
                    {value.__class__.__name__}"
            )

    @property
    def hyper_parameter_optimization_method(self):
        print("Getting value for hyper_parameter_optimization_method")
        return self._hyper_parameter_optimization_method

    @hyper_parameter_optimization_method.setter
    def hyper_parameter_optimization_method(self, value):
        print("Setting value for hyper_parameter_optimization_method")
        if (
            value.lower() == "optuna"
            or value.lower() == "grid"
            or value.lower() == "random"
        ):
            self._hyper_parameter_optimization_method = value
        else:
            raise ValueError(
                f"error occures during selecting optimization_method, {value} is \
                     not supported."
            )

    @property
    def shap_version(self):
        print("Getting value for shap_version")
        return self._shap_version

    @shap_version.setter
    def shap_version(self, value):
        print("Setting value for shap_version")
        self._shap_version = value

    @property
    def measure_of_accuracy(self):
        print("Getting value for measure_of_accuracy")
        return self._measure_of_accuracy

    @measure_of_accuracy.setter
    def measure_of_accuracy(self, value):
        print("Setting value for measure_of_accuracy")
        self._measure_of_accuracy = value

    @property
    def list_of_obligatory_features(self):
        print("Getting value for list_of_obligatory_features")
        return self._list_of_obligatory_features

    @list_of_obligatory_features.setter
    def list_of_obligatory_features(self, value):
        print("Setting value for list_of_obligatory_features")
        self._list_of_obligatory_features = value

    @property
    def test_size(self):
        print("Getting value for test_size")
        return self._test_size

    @test_size.setter
    def test_size(self, value):
        print("Setting value for test_size")
        self._test_size = value

    @property
    def cv(self):
        print("Getting value for Cross Validation object")
        return self._cv

    @cv.setter
    def cv(self, value):
        print("Setting value for Cross Validation object")
        self._cv = value

    @property
    def with_shap_summary_plot(self):
        print("Getting value for with_shap_summary_plot")
        return self._with_shap_summary_plot

    @with_shap_summary_plot.setter
    def with_shap_summary_plot(self, value):
        print("Setting value for with_shap_summary_plot")
        self._with_shap_summary_plot = value

    @property
    def with_shap_interaction_plot(self):
        print("Getting value for with_shap_interaction_plot")
        return self._with_shap_interaction_plot

    @with_shap_interaction_plot.setter
    def with_shap_interaction_plot(self, value):
        print("Setting value for with_shap_interaction_plot")
        self._with_shap_interaction_plot = value

    @property
    def with_stratified(self):
        print("Getting value for with_stratified")
        return self._with_stratified

    @with_stratified.setter
    def with_stratified(self, value):
        print("Setting value for with_stratified")
        self._with_stratified = value

    @property
    def verbose(self):
        print("Getting value for verbose")
        return self._verbose

    @verbose.setter
    def verbose(self, value):
        print("Setting value for verbose")
        self._verbose = value

    @property
    def random_state(self):
        print("Getting value for random_state")
        return self._random_state

    @random_state.setter
    def random_state(self, value):
        print("Setting value for random_state")
        self._random_state = value

    @property
    def n_jobs(self):
        print("Getting value for n_jobs")
        return self._n_jobs

    @n_jobs.setter
    def n_jobs(self, value):
        print("Setting value for n_jobs")
        self._n_jobs = value

    @property
    def n_iter(self):
        print("Getting value for n_iter")
        return self._n_iter

    @n_iter.setter
    def n_iter(self, value):
        print("Setting value for n_iter")
        self._n_iter = value

    @property
    def eval_metric(self):
        print("Getting value for eval_metric")
        return self._eval_metric

    @eval_metric.setter
    def eval_metric(self, value):
        print("Setting value for eval_metric")
        self._eval_metric = value

    @property
    def number_of_trials(self):
        print("Getting value for number_of_trials")
        return self._number_of_trials

    @number_of_trials.setter
    def number_of_trials(self, value):
        print("Setting value for number_of_trials")
        self._number_of_trials = value

    @property
    def sampler(self):
        print("Getting value for sampler")
        return self._sampler

    @sampler.setter
    def sampler(self, value):
        print("Setting value for sampler")
        self._sampler = value

    @property
    def pruner(self):
        print("Getting value for pruner")
        return self._pruner

    @pruner.setter
    def pruner(self, value):
        print("Setting value for pruner")
        self._pruner = value

    @property
    def importance_df(self):
        print("Getting value for importance_df")
        return self._importance_df

    @importance_df.setter
    def importance_df(self, value):
        print("Setting value for importance_df")
        self._importance_df = value

    @property
    def best_estimator(self):
        print("Getting value for best_estimator")
        return self._best_estimator

    @best_estimator.setter
    def best_estimator(self, value):
        print("Setting value for best_estimator")
        self._best_estimator = value

    def fit(self, X, y):

        self.cols = X.columns
        if self.hyper_parameter_optimization_method.lower() == "grid":
            self.best_estimator = _calc_best_estimator_grid_search(
                X,
                y,
                self.estimator,
                self.estimator_params,
                self.measure_of_accuracy,
                self.verbose,
                self.n_jobs,
                self.cv,
            )
        if self.hyper_parameter_optimization_method.lower() == "random":
            self.best_estimator = _calc_best_estimator_random_search(
                X,
                y,
                self.estimator,
                self.estimator_params,
                self.measure_of_accuracy,
                self.verbose,
                self.n_jobs,
                self.n_iter,
                self.cv,
            )
        if self.hyper_parameter_optimization_method.lower() == "optuna":
            self.best_estimator = _calc_best_estimator_optuna_univariate(
                X,
                y,
                self.estimator,
                self.measure_of_accuracy,
                self.estimator_params,
                self.verbose,
                self.test_size,
                self.random_state,
                self.eval_metric,
                self.number_of_trials,
                self.sampler,
                self.pruner,
                self.with_stratified,
            )

        shap_explainer = fasttreeshap.TreeExplainer(
            self.best_estimator, algorithm=self.shap_version, n_jobs=self.n_jobs
        )
        shap_values_v0 = shap_explainer(X).values
        shap_values_v0.shape
        shap_values = shap_explainer.shap_values(X)
        print(shap_values)
        shap_sum = np.abs(shap_values).mean(axis=0)
        self.importance_df = pd.DataFrame([X.columns.tolist(), shap_sum.tolist()]).T
        self.importance_df.columns = ["column_name", "shap_importance"]
        self.importance_df = self.importance_df.sort_values(
            "shap_importance", ascending=False
        )
        print(self.importance_df[0 : self.n_features])
        num_feat = min([self.n_features, self.importance_df.shape[0]])
        self.selected_cols = self.importance_df["column_name"][0:num_feat].to_list()
        shap.summary_plot(shap_values, X, max_display=self.n_features)

        return self

    def transform(self, X):

        return X[self.selected_cols]



import click


@click.command()
@click.option("--count", default=1, help="Number of greetings.")
@click.option("--name", prompt="Your name", help="The person to greet.")
def cli(count, name):
    """Simple program that greets NAME for a total of COUNT times."""
    for x in range(count):
        click.echo(f"Hello {name}!")


@click.group()
def cligroup():
    pass


@cligroup.command()
@click.option(
    "--greeting",
    prompt="greeting from scally shap :)",
    help="Develop this for using command line!",
    default="Greeting from scally shap :)",
)
def greeting(greeting):
    click.echo(greeting)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['zoish', 'zoish.feature_selectors', 'zoish.notebooks', 'zoish.utils']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.1.3,<9.0.0',
 'fasttreeshap>=0.1.2,<0.2.0',
 'feature-engine>=1.4.1,<2.0.0',
 'matplotlib>=3.5.2,<4.0.0',
 'numba>=0.55.2,<0.56.0',
 'numpy<1.24.0',
 'optuna>=2.10.1,<3.0.0',
 'pandas>=1.4.3,<2.0.0',
 'pip-licenses>=3.5.4,<4.0.0',
 'scikit-learn>=1.1.1,<2.0.0',
 'scipy>=1.8.1,<2.0.0',
 'shap>=0.41.0,<0.42.0',
 'xgboost>=1.6.1,<2.0.0']

setup_kwargs = {
    'name': 'zoish',
    'version': '1.24.0',
    'description': 'This project uses shapely values for selecting Top n features compatible with scikit learn pipeline',
    'long_description': None,
    'author': 'drhosseinjavedani',
    'author_email': 'h.javedani@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/drhosseinjavedani/zoish',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<3.11',
}


setup(**setup_kwargs)
